MenuItemModel class
Constructors
- MenuItemModel({required String title, required String icon, required String route})
-
MenuItemModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonList(
List jsonList) → List< MenuItemModel>